@@ -78,7 +78,7 @@ def full_phn_boxplot(asr_model,
                      DR=[0,None],
                      styling_outliers = False):
     asr_dict = load_asr_dict(TIMIT_dict=TIMIT_dict,asr_model=asr_model,DR=DR,file_set=file_set)
-    phn_counter_dict = compare_phonemes_perc(asr_dict=asr_dict,DR=DR,file_set=file_set)
+    phn_counter_dict = compare_phonemes_perc(TIMIT_dict=TIMIT_dict,asr_dict=asr_dict,DR=DR,file_set=file_set)
 
     return phn_boxplot(phn_counter_dict,styling_outliers=styling_outliers)
 
